// 
// SoapTrace.Net - A soap message monitoring utility. 
// 
// Copyright (C) 2004 Matthew Ward
// 
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
// 
// Matthew Ward (mrward@users.sourceforge.net)
// 

using Microsoft.Win32;
using System;
using System.Runtime.Remoting;
using System.Runtime.Remoting.Channels;
//using System.Runtime.Remoting.Channels.Tcp;
using System.Windows.Forms;

namespace SoapTrace.Core.ApplicationFramework
{
	/// <summary>
	/// Remoting client for a single instance application.
	/// </summary>
	public class SingleInstanceClient
	{
		private ISingleInstanceApplicationContext m_Context;

		/// <summary>
		/// Create a new instance of the remoting client.
		/// </summary>
		/// <param name="context">Application context.</param>
		public SingleInstanceClient( ISingleInstanceApplicationContext context )
		{
			m_Context = context;
		}

		/// <summary>
		/// Sends the second instances command line to the first instance for 
		/// processing.
		/// </summary>
		/// <param name="args">Command line arguments.</param>
		/// <returns></returns>
		public int RunSecondInstance( string[ ] args )
		{
			// Locate server.

			string Url = String.Empty;

			using( RegistryKey Key = Application.UserAppDataRegistry ) 
			{
				Url = ( string )Key.GetValue( m_Context.GetType( ).FullName );
			}

			// Send message to server.

			FirstInstance Instance = 
				( FirstInstance )RemotingServices.Connect( 
					typeof( FirstInstance ), Url );

			return Instance.RunSecondInstance( args );
		}
	}
}
