// 
// SoapTrace.Net - A soap message monitoring utility. 
// 
// Copyright (C) 2004 Matthew Ward
// 
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
// 
// Matthew Ward (mrward@users.sourceforge.net)
// 

using System;

namespace SoapTrace.Core.Communication
{
	/// <summary>
	/// An interface for a soap message.
	/// </summary>
	public interface ISoapMessage
	{
		/// <summary>
		/// Gets the soap message.
		/// </summary>
		string Message{	get; }

		/// <summary>
		/// Gets the Http header.
		/// </summary>
		string Header{ get; }

		/// <summary>
		/// Gets or sets the time this message was received.
		/// </summary>
		DateTime TimeReceived{ get; set; }

		/// <summary>
		/// Adds a single Http message byte to the soap message.
		/// </summary>
		/// <param name="messageByte"></param>
		/// <returns></returns>
		bool AddByte( byte messageByte );

		/// <summary>
		/// Clears the soap message.
		/// </summary>
		void Clear( );
	}
}
