// 
// SoapTrace.Net - A soap message monitoring utility. 
// 
// Copyright (C) 2004 Matthew Ward
// 
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
// 
// Matthew Ward (mrward@users.sourceforge.net)
// 


using SoapTrace.Core.Communication;
using System;

namespace SoapTrace.Core
{
	/// <summary>
	/// Represents a monitored client used by the 
	/// <see cref="SoapPacketMonitor"/> class so it can
	/// handle multiple clients at the same time.
	/// </summary>
	public class SoapPacketClient
	{
		/// <summary>
		/// The soap request associated with this client.
		/// </summary>
		private SoapRequest m_SoapRequest = new SoapRequest( );
		
		/// <summary>
		/// The soap response associated with this client.
		/// </summary>
		private SoapResponse m_SoapResponse = new SoapResponse( );
		
		/// <summary>
		/// The local end point IP address and port string.</summary>
		private string m_LocalEndPoint = String.Empty;
		
		/// <summary>
		/// The client Id.
		/// </summary>
		private ClientId m_ClientId = new ClientId( );
		
		/// <summary>
		/// Creates a new instance of the <see cref="SoapPacketClient"/>
		/// class.
		/// </summary>
		public SoapPacketClient( )
		{
		}
		
		/// <summary>
		/// Gets or sets the soap request associated with this
		/// client.
		/// </summary>
		public SoapRequest SoapRequest
		{
			get
			{
				return m_SoapRequest;
			}
			
			set
			{
				m_SoapRequest = value;
			}
		}
		
		/// <summary>
		/// Gets or sets the soap response associated with this
		/// client.
		/// </summary>
		public SoapResponse SoapResponse
		{
			get
			{
				return m_SoapResponse;
			}
			
			set
			{
				m_SoapResponse = value;
			}
		}	

		/// <summary>
		/// Gets or sets the client's local end point string.
		/// </summary>
		public string LocalEndPoint 
		{
			get 
			{
				return m_LocalEndPoint;
			}
			
			set 
			{
				m_LocalEndPoint = value;
			}
		}
	
		/// <summary>
		/// Gets or sets the client's Id.
		/// </summary>
		public ClientId Id
		{
			get
			{
				return m_ClientId;
			}
			
			set
			{
				m_ClientId = value;
			}
		}
	}
}
