//
// SoapTrace.Net - A soap message monitoring utility. 
//
// Copyright (C) 2004 Matthew Ward
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
// Matthew Ward (mrward@users.sourceforge.net)

using System;

namespace SoapTrace.Core.Communication
{
	/// <summary>
	/// Holds the arguments for the 
	/// <see cref="SoapRequestMessageReceivedEventHandler"/>
	/// </summary>
	public class SoapRequestReceivedEventArgs : EventArgs
	{
		/// <summary>
		/// Client id.
		/// </summary>
		private ClientId m_ClientId;
		
		/// <summary>
		/// The soap request.
		/// </summary>
		private SoapRequest m_Request;
		
		/// <summary>
		/// Creates a new instance of the <see cref="SoapRequestReceivedEventArgs"/>
		/// class.
		/// </summary>
		/// <param name="clientId">The id of the client.</param>
		/// <param name="request">A <see cref="SoapRequest"/></param>
		public SoapRequestReceivedEventArgs( ClientId clientId, SoapRequest request )
		{
			m_ClientId = clientId;
			
			m_Request = request;
		}
		
		/// <summary>
		/// Gets or sets the client id.
		/// </summary>
		public ClientId ClientId
		{
			get
			{
				return m_ClientId;
			}
			
			set
			{
				m_ClientId = value;
			}
		}
		
		/// <summary>
		/// Gets or sets the soap request.
		/// </summary>
		public SoapRequest Request 
		{
			get 
			{
				return m_Request;
			}
			set 
			{
				m_Request = value;
			}
		}
	}
}
