//
// SoapTrace.Net - A soap message monitoring utility. 
//
// Copyright (C) 2004 Matthew Ward
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
// Matthew Ward (mrward@users.sourceforge.net)

using System;

namespace SoapTrace.Core.Communication
{
	/// <summary>
	/// Holds the arguments for the 
	/// <see cref="SoapResponseMessageReceivedEventHandler"/>
	/// </summary>
	public class SoapResponseReceivedEventArgs : EventArgs
	{
		/// <summary>
		/// Client id.
		/// </summary>
		private ClientId m_ClientId;		
		
		/// <summary>
		/// The soap response.
		/// </summary>
		private SoapResponse m_Response;
		
		/// <summary>
		/// Creates a new instance of the <see cref="SoapResponseReceivedEventArgs"/>
		/// class.
		/// </summary>
		/// <param name="clientId">The id of the client.</param>
		/// <param name="response">A <see cref="SoapResponse"/></param>
		public SoapResponseReceivedEventArgs( ClientId clientId, SoapResponse response )
		{
			m_ClientId = clientId;
			
			m_Response = response;
		}
		
		/// <summary>
		/// Gets or sets the client id.
		/// </summary>
		public ClientId ClientId 
		{
			get 
			{
				return m_ClientId;
			}
			
			set 
			{
				m_ClientId = value;
			}
		}
		
		/// <summary>
		/// Gets or sets the soap response.
		/// </summary>
		public SoapResponse Response 
		{
			get 
			{
				return m_Response;
			}
			set 
			{
				m_Response = value;
			}
		}
	}
}
