//
// SoapTrace.Net - A soap message monitoring utility. 
//
// Copyright (C) 2005 Matthew Ward
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
// Matthew Ward (mrward@users.sourceforge.net)


using System;
using System.Net;

namespace SoapTrace.Core.Communication
{
	/// <summary>
	/// Event arguments for the <see cref="TcpCommunicationEventHandler"/>.
	/// </summary>
	public class TcpCommunicationEventArgs
	{
		private IPEndPoint m_SourceAddress;
		private IPEndPoint m_DestinationAddress;
		private byte[ ] m_Bytes;
		
		/// <summary>
		/// Creates a new instance of the 
		/// <see cref="TcpCommunicationEventArgs"/>.
		/// </summary>
		public TcpCommunicationEventArgs( )
		{
		}
		
		/// <summary>
		/// Creates a new instance of the 
		/// <see cref="TcpCommunicationEventArgs"/>.
		/// </summary>
		/// <param name="sourceAddress">The source IP address.</param>
		/// <param name="destinationAddress">The destination IP address.</param>
		public TcpCommunicationEventArgs( IPEndPoint sourceAddress, IPEndPoint destinationAddress )
			: this( sourceAddress, destinationAddress, null )
		{
		}
		
		/// <summary>
		/// Creates a new instance of the 
		/// <see cref="TcpCommunicationEventArgs"/>.
		/// </summary>
		/// <param name="sourceAddress">The source IP address.</param>
		/// <param name="destinationAddress">The destination IP address.</param>
		/// <param name="bytes">The bytes associated with the event.</param>
		public TcpCommunicationEventArgs( IPEndPoint sourceAddress, IPEndPoint destinationAddress, byte[ ] bytes )
		{
			m_SourceAddress = sourceAddress;
			m_DestinationAddress = destinationAddress;
			m_Bytes = bytes;
		}
		
		/// <summary>
		/// The source IP address associated with the communication
		/// event.
		/// </summary>
		public IPEndPoint SourceAddress
		{
			get
			{
				return m_SourceAddress;
			}
		}
		
		/// <summary>
		/// The destination IP address associated with the communication
		/// event.
		/// </summary>
		public IPEndPoint DestinationAddress
		{
			get
			{
				return m_DestinationAddress;
			}
		}	
		
		/// <summary>
		/// Gets the bytes associated with the event.
		/// </summary>
		/// <returns>A byte array.</returns>
		public byte[ ] GetBytes( )
		{
			return m_Bytes;
		}
	}
}
