//
// SoapTrace.Net - A soap message monitoring utility. 
//
// Copyright (C) 2005 Matthew Ward
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
// Matthew Ward (mrward@users.sourceforge.net)

using SoapTrace.Core.Communication;
using System;

namespace SoapTrace.Core.Diagnostics
{
	/// <summary>
	/// Interface for all soap message loggers.
	/// </summary>
	public interface ISoapMessageLogger
	{
		/// <summary>
		/// Called when a soap request and response have arrived.
		/// </summary>
		/// <param name="serverAddressFilter">The remote server's IP address
		/// or host name used when filtering.</param>
		/// <param name="serverPortFilter">The remote server's port
		/// used when filtering.
		/// </param>
		/// <param name="requestAndResponse">The soap request and 
		/// response.</param>
		void Log( string serverAddressFilter, 
			int serverPortFilter, 
			SoapRequestAndResponse requestAndResponse );
		
		/// <summary>
		/// Turns logging on or off.
		/// </summary>
		bool Enabled { get; set; }
		
		/// <summary>
		/// Sets the logging folder.
		/// </summary>
		string Folder { get; set; }
	}
}
