//
// SoapTrace.Net - A soap message monitoring utility. 
//
// Copyright (C) 2004 Matthew Ward
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
// Matthew Ward (mrward@users.sourceforge.net)

using System;

namespace SoapTrace.Core.Diagnostics
{
	/// <summary>
	/// Provides data for the <see cref="Logger.LogEntryAdded"/> event.
	/// </summary>
	public class LogEventArgs : EventArgs
	{
		/// <summary>
		/// The <see cref="LogEntry"/> associated with the event.
		/// </summary>
		private LogEntry m_LogEntry;
		
		/// <summary>
		/// Creates a new instance of the <see cref="LogEventArgs"/> class.
		/// </summary>
		public LogEventArgs( )
		{
		}
		
		/// <summary>
		/// Creates a new instance of the <see cref="LogEventArgs"/> class.
		/// </summary>
		/// <param name="entry">The <see cref="LogEntry"/> associated 
		/// with the event.</param>
		public LogEventArgs( LogEntry entry )
		{
			m_LogEntry = entry;
		}
		
		/// <summary>
		/// Gets the <see cref="LogEntry"/> associated with the 
		/// log event.
		/// </summary>
		public LogEntry LogEntry
		{
			get
			{
				return m_LogEntry;
			}
		}
	}
}
