//
// SoapTrace.Net - A soap message monitoring utility. 
//
// Copyright (C) 2005 Matthew Ward
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
// Matthew Ward (mrward@users.sourceforge.net)

using System;
using System.Drawing;

namespace SoapTrace.Core.Formatters
{
	/// <summary>
	/// Represents a piece of text with a single colour inside a 
	/// <see cref="FormattedText"/> string.
	/// </summary>
	public class FormattedTextItem
	{
		/// <summary>
		/// The string associated with this item.
		/// </summary>
		private string m_Text = String.Empty;
		
		/// <summary>
		/// The colour of the text.
		/// </summary>
		private Color m_TextColour = Color.Black;
		
		/// <summary>
		/// Creates a new instance of the <see cref="FormattedTextItem"/> 
		/// class.
		/// </summary>
		public FormattedTextItem( string text, Color colour )
		{
			m_Text = text;
			m_TextColour = colour;
		}
		
		/// <summary>
		/// Gets the formatted item's text.
		/// </summary>
		public string Text
		{
			get
			{
				return m_Text;
			}
		}
		
		/// <summary>
		/// Gets or sets the text colour.
		/// </summary>
		public Color Colour
		{
			get
			{
				return m_TextColour;
			}
			
			set
			{
				m_TextColour = value;
			}
		}		
	}
}
