//
// SoapTrace.Net - A soap message monitoring utility. 
//
// Copyright (C) 2006 Matthew Ward
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
// Matthew Ward (mrward@users.sourceforge.net)

using System;

namespace SoapTrace.Core.Formatters
{
	/// <summary>
	/// Represents a single line of text.
	/// </summary>
	public class Line
	{
		string m_Text = String.Empty;
		string m_Terminator = String.Empty;
		
		/// <summary>
		/// Creates a new instance of the <see cref="Line"/> class.
		/// </summary>
		/// <param name="text">The line's text.</param>
		/// <param name="terminator">The text used to terminate lines.</param>
		public Line( string text, string terminator )
		{
			m_Text = text;
			m_Terminator = terminator;
		}
		
		/// <summary>
		/// Creates a new instance of the <see cref="Line"/> class with no
		/// line terminator.
		/// </summary>
		/// <param name="text">The line's text.</param>
		public Line( string text ) : this( text, String.Empty )
		{
		}
		
		/// <summary>
		/// Gets the line's text.
		/// </summary>
		public string Text
		{
			get
			{
				return m_Text;
			}
		}
		
		/// <summary>
		/// Gets the line's length excluding any terminator marker.
		/// </summary>
		public int Length
		{
			get
			{
				return m_Text.Length;
			}
		}
		
		/// <summary>
		/// Gets the line terminator's text.
		/// </summary>
		public string Terminator
		{
			get
			{
				return m_Terminator;
			}
		}
	}
}
