//
// SoapTrace.Net - A soap message monitoring utility. 
//
// Copyright (C) 2004 Matthew Ward
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
// Matthew Ward (mrward@users.sourceforge.net)

using System;
using System.Xml.Serialization;

namespace SoapTrace.Core.Formatters
{
	/// <summary>
	/// Represents a single array item of a <see cref="WebServiceParameter"/>
	/// or a <see cref="WebServiceReturnValue"/>
	/// </summary>
	[ XmlType( "item" ) ] 
	public class WebServiceArrayItem
	{
		/// <summary>
		/// The array item type.
		/// </summary>
		private string m_ItemType = String.Empty;
		
		/// <summary>
		/// The array item's name.
		/// </summary>
		private string m_Name = String.Empty;
		
		/// <summary>
		/// A flag indicating whether to display the array item in the GUI or not.
		/// </summary>
		private bool m_Display = true;
		
		/// <summary>
		/// Creates a new instance of the <see cref="WebServiceArrayItem"/>
		/// </summary>
		public WebServiceArrayItem( )
		{
		}
		
		/// <summary>
		/// Gets or sets the array item type.
		/// </summary>
		[ XmlAttribute( "type" ) ]
		public string ItemType
		{
			get
			{
				return m_ItemType;
			}

			set
			{
				m_ItemType = value;
			}
		}

		/// <summary>
		/// Gets or sets the array item's name.
		/// </summary>
		[ XmlAttribute( "name" ) ]
		public string Name
		{
			get
			{
				return m_Name;
			}

			set
			{
				m_Name = value;
			}
		}

		/// <summary>
		/// Gets or sets a flag indicating whether to display
		/// this array item or not.
		/// </summary>
		[ XmlAttribute( "display" ) ]
		public bool Display
		{
			get
			{
				return m_Display;
			}

			set
			{
				m_Display = value;
			}
		}		
	}
}
