//
// SoapTrace.Net - A soap message monitoring utility. 
//
// Copyright (C) 2005 Matthew Ward
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
// Matthew Ward (mrward@users.sourceforge.net)


using System;
using System.Collections;

namespace SoapTrace.Core
{
	/// <summary>
	///   A collection that stores <see cref='MonitorManagerConfiguration'/> objects.
	/// </summary>
	[Serializable()]
	public class MonitorManagerConfigurationCollection : CollectionBase {
		
		/// <summary>
		///   Initializes a new instance of <see cref='MonitorManagerConfigurationCollection'/>.
		/// </summary>
		public MonitorManagerConfigurationCollection()
		{
		}
		
		/// <summary>
		///   Initializes a new instance of <see cref='MonitorManagerConfigurationCollection'/> based on another <see cref='MonitorManagerConfigurationCollection'/>.
		/// </summary>
		/// <param name='val'>
		///   A <see cref='MonitorManagerConfigurationCollection'/> from which the contents are copied
		/// </param>
		public MonitorManagerConfigurationCollection(MonitorManagerConfigurationCollection val)
		{
			this.AddRange(val);
		}
		
		/// <summary>
		///   Initializes a new instance of <see cref='MonitorManagerConfigurationCollection'/> containing any array of <see cref='MonitorManagerConfiguration'/> objects.
		/// </summary>
		/// <param name='val'>
		///       A array of <see cref='MonitorManagerConfiguration'/> objects with which to intialize the collection
		/// </param>
		public MonitorManagerConfigurationCollection(MonitorManagerConfiguration[] val)
		{
			this.AddRange(val);
		}
		
		/// <summary>
		///   Represents the entry at the specified index of the <see cref='MonitorManagerConfiguration'/>.
		/// </summary>
		/// <param name='index'>The zero-based index of the entry to locate in the collection.</param>
		/// <value>The entry at the specified index of the collection.</value>
		/// <exception cref='ArgumentOutOfRangeException'><paramref name='index'/> is outside the valid range of indexes for the collection.</exception>
		public MonitorManagerConfiguration this[int index] {
			get {
				return ((MonitorManagerConfiguration)(List[index]));
			}
			set {
				List[index] = value;
			}
		}
		
		/// <summary>
		///   Adds a <see cref='MonitorManagerConfiguration'/> with the specified value to the 
		///   <see cref='MonitorManagerConfigurationCollection'/>.
		/// </summary>
		/// <param name='val'>The <see cref='MonitorManagerConfiguration'/> to add.</param>
		/// <returns>The index at which the new element was inserted.</returns>
		/// <seealso cref='MonitorManagerConfigurationCollection.AddRange'/>
		public int Add(MonitorManagerConfiguration val)
		{
			return List.Add(val);
		}
		
		/// <summary>
		///   Copies the elements of an array to the end of the <see cref='MonitorManagerConfigurationCollection'/>.
		/// </summary>
		/// <param name='val'>
		///    An array of type <see cref='MonitorManagerConfiguration'/> containing the objects to add to the collection.
		/// </param>
		/// <seealso cref='MonitorManagerConfigurationCollection.Add'/>
		public void AddRange(MonitorManagerConfiguration[] val)
		{
			for (int i = 0; i < val.Length; i++) {
				this.Add(val[i]);
			}
		}
		
		/// <summary>
		///   Adds the contents of another <see cref='MonitorManagerConfigurationCollection'/> to the end of the collection.
		/// </summary>
		/// <param name='val'>
		///    A <see cref='MonitorManagerConfigurationCollection'/> containing the objects to add to the collection.
		/// </param>
		/// <seealso cref='MonitorManagerConfigurationCollection.Add'/>
		public void AddRange(MonitorManagerConfigurationCollection val)
		{
			for (int i = 0; i < val.Count; i++)
			{
				this.Add(val[i]);
			}
		}
		
		/// <summary>
		///   Gets a value indicating whether the 
		///    <see cref='MonitorManagerConfigurationCollection'/> contains the specified <see cref='MonitorManagerConfiguration'/>.
		/// </summary>
		/// <param name='val'>The <see cref='MonitorManagerConfiguration'/> to locate.</param>
		/// <returns>
		/// <see langword='true'/> if the <see cref='MonitorManagerConfiguration'/> is contained in the collection; 
		///   otherwise, <see langword='false'/>.
		/// </returns>
		/// <seealso cref='MonitorManagerConfigurationCollection.IndexOf'/>
		public bool Contains(MonitorManagerConfiguration val)
		{
			return List.Contains(val);
		}
		
		/// <summary>
		///   Copies the <see cref='MonitorManagerConfigurationCollection'/> values to a one-dimensional <see cref='Array'/> instance at the 
		///    specified index.
		/// </summary>
		/// <param name='array'>The one-dimensional <see cref='Array'/> that is the destination of the values copied from <see cref='MonitorManagerConfigurationCollection'/>.</param>
		/// <param name='index'>The index in <paramref name='array'/> where copying begins.</param>
		/// <exception cref='ArgumentException'>
		///   <para><paramref name='array'/> is multidimensional.</para>
		///   <para>-or-</para>
		///   <para>The number of elements in the <see cref='MonitorManagerConfigurationCollection'/> is greater than
		///         the available space between <paramref name='arrayIndex'/> and the end of
		///         <paramref name='array'/>.</para>
		/// </exception>
		/// <exception cref='ArgumentNullException'><paramref name='array'/> is <see langword='null'/>. </exception>
		/// <exception cref='ArgumentOutOfRangeException'><paramref name='arrayIndex'/> is less than <paramref name='array'/>'s lowbound. </exception>
		/// <seealso cref='Array'/>
		public void CopyTo(MonitorManagerConfiguration[] array, int index)
		{
			List.CopyTo(array, index);
		}
		
		/// <summary>
		///    Returns the index of a <see cref='MonitorManagerConfiguration'/> in 
		///       the <see cref='MonitorManagerConfigurationCollection'/>.
		/// </summary>
		/// <param name='val'>The <see cref='MonitorManagerConfiguration'/> to locate.</param>
		/// <returns>
		///   The index of the <see cref='MonitorManagerConfiguration'/> of <paramref name='val'/> in the 
		///   <see cref='MonitorManagerConfigurationCollection'/>, if found; otherwise, -1.
		/// </returns>
		/// <seealso cref='MonitorManagerConfigurationCollection.Contains'/>
		public int IndexOf(MonitorManagerConfiguration val)
		{
			return List.IndexOf(val);
		}
		
		/// <summary>
		///   Inserts a <see cref='MonitorManagerConfiguration'/> into the <see cref='MonitorManagerConfigurationCollection'/> at the specified index.
		/// </summary>
		/// <param name='index'>The zero-based index where <paramref name='val'/> should be inserted.</param>
		/// <param name='val'>The <see cref='MonitorManagerConfiguration'/> to insert.</param>
		/// <seealso cref='MonitorManagerConfigurationCollection.Add'/>
		public void Insert(int index, MonitorManagerConfiguration val)
		{
			List.Insert(index, val);
		}
		
		/// <summary>
		///  Returns an enumerator that can iterate through the <see cref='MonitorManagerConfigurationCollection'/>.
		/// </summary>
		/// <seealso cref='IEnumerator'/>
		public new MonitorManagerConfigurationEnumerator GetEnumerator()
		{
			return new MonitorManagerConfigurationEnumerator(this);
		}
		
		/// <summary>
		///   Removes a specific <see cref='MonitorManagerConfiguration'/> from the <see cref='MonitorManagerConfigurationCollection'/>.
		/// </summary>
		/// <param name='val'>The <see cref='MonitorManagerConfiguration'/> to remove from the <see cref='MonitorManagerConfigurationCollection'/>.</param>
		/// <exception cref='ArgumentException'><paramref name='val'/> is not found in the Collection.</exception>
		public void Remove(MonitorManagerConfiguration val)
		{
			List.Remove(val);
		}
		
		/// <summary>
		///   Enumerator that can iterate through a MonitorManagerConfigurationCollection.
		/// </summary>
		/// <seealso cref='IEnumerator'/>
		/// <seealso cref='MonitorManagerConfigurationCollection'/>
		/// <seealso cref='MonitorManagerConfiguration'/>
		public class MonitorManagerConfigurationEnumerator : IEnumerator
		{
			IEnumerator baseEnumerator;
			IEnumerable temp;
			
			/// <summary>
			///   Initializes a new instance of <see cref='MonitorManagerConfigurationEnumerator'/>.
			/// </summary>
			public MonitorManagerConfigurationEnumerator(MonitorManagerConfigurationCollection mappings)
			{
				this.temp = ((IEnumerable)(mappings));
				this.baseEnumerator = temp.GetEnumerator();
			}
			
			/// <summary>
			///   Gets the current <see cref='MonitorManagerConfiguration'/> in the <seealso cref='MonitorManagerConfigurationCollection'/>.
			/// </summary>
			public MonitorManagerConfiguration Current {
				get {
					return ((MonitorManagerConfiguration)(baseEnumerator.Current));
				}
			}
			
			object IEnumerator.Current {
				get {
					return baseEnumerator.Current;
				}
			}
			
			/// <summary>
			///   Advances the enumerator to the next <see cref='MonitorManagerConfiguration'/> of the <see cref='MonitorManagerConfigurationCollection'/>.
			/// </summary>
			public bool MoveNext()
			{
				return baseEnumerator.MoveNext();
			}
			
			/// <summary>
			///   Sets the enumerator to its initial position, which is before the first element in the <see cref='MonitorManagerConfigurationCollection'/>.
			/// </summary>
			public void Reset()
			{
				baseEnumerator.Reset();
			}
		}
	}
}
