//
// SoapTrace.Net - A soap message monitoring utility. 
//
// Copyright (C) 2005 Matthew Ward
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
// Matthew Ward (mrward@users.sourceforge.net)


using NUnit.Framework;
using SoapTrace.Core.Communication;
using System;

namespace SoapTrace.Tests
{
	/// <summary>
	/// Tests the <see cref="ClientId"/> class.
	/// </summary>
	[ TestFixture ]
	public class ClientIdTestFixture
	{
		/// <summary>
		/// Check a different IP address, but same port creates
		/// a different client id.
		/// </summary>
		[ Test ]
		public void DifferentIds( )
		{
			ClientId Id1 = new ClientId( );
			ClientId Id2 = new ClientId( );
			
			Assert.IsFalse( Id1 == Id2, "Ids should be different." );
		}
		
		/// <summary>
		/// Check that we get a match for the same client id.
		/// </summary>
		[ Test ]
		public void SameId( )
		{
			ClientId Id1 = new ClientId( );
			ClientId Id2 = Id1;
			
			Assert.AreEqual( Id2, Id1, "Should be identical." );
		}
	}
}
