// 
// SoapTrace.Net - A soap message monitoring utility. 
// 
// Copyright (C) 2004 Matthew Ward
// 
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
// 
// Matthew Ward (mrward@users.sourceforge.net)
// 

using NUnit.Framework;
using SoapTrace.Core;
using SoapTrace.Tests.Config;
using System;
using System.IO;
using System.Xml;

namespace SoapTrace.Tests
{
	/// <summary>
	/// Tests the <see cref="SoapTrace.Core.XmlSerializerConfigSectionHandler"/> 
	/// class.
	/// </summary>
	[ TestFixture ]
	public class ConfigSectionHandlerTestFixture
	{
		/// <summary>
		/// Section handler to test.
		/// </summary>
		private XmlSerializerConfigSectionHandler m_Handler;

		/// <summary>
		/// Test config section created by the section handler.
		/// </summary>
		private TestConfigSection m_ConfigSection;

		/// <summary>
		/// Initialises this test fixture.
		/// </summary>
		[ TestFixtureSetUp ]
		public void Init( )
		{
			string ConfigXml = "<TestConfigSection type =\"SoapTrace.Tests.Config.TestConfigSection, SoapTrace.Tests\">\r\n" +
				"\t<Foo>Foo</Foo>\r\n" +
				"\t<Bar>Bar</Bar>\r\n" +
				"</TestConfigSection> ";
			
			StringReader Reader = new StringReader( ConfigXml );
			
			// Load the test config file.
			XmlDocument Document = new XmlDocument( );
			Document.Load( Reader );

			m_Handler = new XmlSerializerConfigSectionHandler( );

			m_ConfigSection = ( TestConfigSection )m_Handler.Create( null, 
				null, Document.DocumentElement );
		}

		/// <summary>
		/// Checks the values in the TestConfigSection object that
		/// was serialised into by the section handler object.
		/// </summary>
		[ Test ]
		public void CheckConfigValues( )
		{
			Assert.AreEqual( "Foo", m_ConfigSection.Foo );
			Assert.AreEqual( "Bar", m_ConfigSection.Bar );
		}
	}
}
