//
// SoapTrace.Net - A soap message monitoring utility. 
//
// Copyright (C) 2006 Matthew Ward
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
// Matthew Ward (mrward@users.sourceforge.net)

using NUnit.Framework;
using SoapTrace.Core.Formatters;
using System;

namespace SoapTrace.Tests.Lines
{
	/// <summary>
	/// Tests the <see cref="LineCollection"/> class with an empty line.
	/// </summary>
	[ TestFixture ]
	public class EmptyLineTestFixture
	{
		LineCollection Lines;
		Line Line;
		
		/// <summary>
		/// Initialises this test.
		/// </summary>
		[ SetUp ]
		public void Init( )
		{
			Lines = LineCollection.GetLines( String.Empty );
			Line = Lines[ 0 ];
		}
		
		/// <summary>
		/// Checks the line count,.
		/// </summary>
		[ Test ]
		public void LineCount( )
		{
			Assert.AreEqual( 1, Lines.Count, "Should be only one line." );
		}
		
		/// <summary>
		/// Checks the text for the one and only line is correct.
		/// </summary>
		[ Test ]
		public void LineText( )
		{
			Assert.AreEqual( String.Empty, Line.Text, "Line text is wrong." );
		}
		
		/// <summary>
		/// Checks the line terminator is empty.
		/// </summary>
		[ Test ]
		public void LineTerminator( )
		{
			Assert.AreEqual( String.Empty, Line.Terminator, "Line's terminator is incorrect" );
		}
		
		/// <summary>
		/// Checks the line's length.
		/// </summary>
		[ Test ]
		public void LineLength( )
		{
			Assert.AreEqual( 0, Line.Length, "Line length is incorrect." );
		}
	}
}
