//
// SoapTrace.Net - A soap message monitoring utility. 
//
// Copyright (C) 2005 Matthew Ward
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
// Matthew Ward (mrward@users.sourceforge.net)

using NUnit.Framework;
using SoapTrace.Core.Communication;
using SoapTrace.Tests.Utils;
using System;
using System.Net;
using System.Net.Sockets;
using System.Text;
using System.Threading;

namespace SoapTrace.Tests.MessagePlayback
{
	/// <summary>
	/// Tests the <see cref="WebServiceClient"/> when 
	/// a soap request was successfully sent and a response 
	/// received.
	/// </summary>
	[ TestFixture ]
	public class DisconnectTestFixture : WebServiceClient
	{
		/// <summary>
		/// Checks the connection state.
		/// </summary>
		[ Test ]
		public void ConnectedState( )
		{
			SoapRequest Request = new SoapRequest( );
			
			this.Connect( "200.1.1.1", 80 );
			
			Assert.IsTrue( this.IsConnected, "Should be connected." );
		}
		
		/// <summary>
		/// Checks the connection state.
		/// </summary>
		[ Test ]
		public void DisconnectedState( )
		{
			SoapRequest Request = new SoapRequest( );
			
			this.Connect( "200.1.1.1", 80 );
			this.Shutdown( );
			
			Assert.IsFalse( this.IsConnected, "Should be disconnected." );
		}	
		
		/// <summary>
		/// Checks the connection state.
		/// </summary>
		[ Test ]
		public void DisconnectedDuringProcessing( )
		{
			SoapRequest Request = new SoapRequest( );
			
			this.Connect( "200.1.1.1", 80 );
			this.Send( new SoapRequest( ) );
			
			Thread.Sleep( 10 );
			
			Assert.IsFalse( this.IsConnected, "Should be disconnected." );
		}			
		
		/// <summary>
		/// Cleans up after test.
		/// </summary>
		[ TestFixtureTearDown ]
		public void TearDown( )
		{
			Shutdown( );
		}		
		
		/// <summary>
		/// Returns a mock tcp socket.
		/// </summary>
		protected override ISocket CreateSocket( AddressFamily addressFamily,
			SocketType socketType,
			ProtocolType protocolType )
		{
			MockTcpSocket MockTcpSocket = new MockTcpSocket( );
			return MockTcpSocket;
		}
		
		/// <summary>
		/// Returns a fake host entry object.
		/// </summary>
		protected override IPHostEntry ResolveAddress( string address )
		{
			IPHostEntry Entry = new IPHostEntry( );
			
			IPAddress IPAddress = IPAddress.Parse( "200.1.1.1" );
			IPAddress[ ] AddressList = new IPAddress[ ] { IPAddress };
			
			Entry.AddressList = AddressList;
			
			return Entry;
		}		
	}
}
