//
// SoapTrace.Net - A soap message monitoring utility. 
//
// Copyright (C) 2005 Matthew Ward
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
// Matthew Ward (mrward@users.sourceforge.net)

using NUnit.Framework;
using SoapTrace.Core.Formatters;
using System;
using System.Drawing;
using System.Windows.Forms;

namespace SoapTrace.Tests.RichTextBoxFormatting
{
	/// <summary>
	/// Base class for all test fixtures that test the
	/// <see cref="RichTextBoxFormatter"/>.
	/// </summary>
	public abstract class RichTextBoxFormatterTestFixtureBase
	{
		RichTextBox m_RichTextBox;
		
		/// <summary>
		/// The rich text box used in the test fixture.
		/// </summary>
		public RichTextBox RichTextBox
		{
			get
			{
				return m_RichTextBox;
			}
			
			set
			{
				m_RichTextBox = value;
			}
		}
		
		/// <summary>
		/// Creates the rich text box.
		/// </summary>
		public void CreateTextBox( )
		{
			m_RichTextBox = new RichTextBox( );
			m_RichTextBox.WordWrap = false;
			m_RichTextBox.Multiline = true;
		}
		
		/// <summary>
		/// Gets the text colour at the specified index.
		/// </summary>
		/// <param name="text">The text that should be at the 
		/// specified index.</param>
		/// <param name="index">The character index.</param>
		protected Color GetTextColour( string text, int index )
		{
			m_RichTextBox.Select( index, text.Length );
			
			Assert.AreEqual( text, m_RichTextBox.SelectedText, "Unexpected text at index." );
			
			return m_RichTextBox.SelectionColor;
		}	
	}
}
