//
// SoapTrace.Net - A soap message monitoring utility. 
//
// Copyright (C) 2005 Matthew Ward
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
// Matthew Ward (mrward@users.sourceforge.net)


using NUnit.Framework;
using System;
using System.Drawing;
using System.Windows.Forms;

namespace SoapTrace.Tests.RichTextBoxHttpHeader
{
	/// <summary>
	/// Formats a rich text box containing a http header.
	/// </summary>
	[ TestFixture ]
	public class FieldFormatTestFixture : RichTextBoxHttpHeaderTestFixtureBase
	{
		string Text = "POST /webservices/latest.asmx HTTP/1.1\r\n" +
			"User-Agent: Mozilla/4.0\r\n" +
			"Content-Type: text/xml\r\n" +
			"\r\n";
		
		/// <summary>
		/// Initialises each test.
		/// </summary>
		[ SetUp ]
		public void Init( )
		{
			base.Init( Text );
		}
		
		/// <summary>
		/// Checks the first field name.
		/// </summary>
		[ Test ]
		public void FirstFieldNameColour( )
		{
			Assert.AreEqual( Formatter.FieldNameColour, GetTextColour( "User-Agent", 39 ), 
			                "First field name text colour is wrong." );
		}	
		
		/// <summary>
		/// Checks the second field name.
		/// </summary>
		[ Test ]
		public void SecondFieldNameColour( )
		{
			Assert.AreEqual( Formatter.FieldNameColour, GetTextColour( "Content-Type", 63 ), 
			                "Second field name text colour is wrong." );
		}			
		
		/// <summary>
		/// Checks the first field's delimiter.
		/// </summary>
		[ Test ]
		public void FirstFieldDelimiterColour( )
		{
			Assert.AreEqual( Formatter.FieldDelimiterColour, GetTextColour( ":", 49 ), 
			                "First field delimiter text colour is wrong." );			
		}
		
		/// <summary>
		/// Checks the first field's value.
		/// </summary>
		[ Test ]
		public void FirstFieldValueColour( )
		{
			Assert.AreEqual( Formatter.FieldValueColour, GetTextColour( "Mozilla/4.0", 51 ), 
			                "First field value text colour is wrong." );			
		}		
	}
}
