//
// SoapTrace.Net - A soap message monitoring utility. 
//
// Copyright (C) 2005 Matthew Ward
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
// Matthew Ward (mrward@users.sourceforge.net)

using NUnit.Framework;
using SoapTrace.Core.Formatters;
using System;
using System.Drawing;
using System.Windows.Forms;

namespace SoapTrace.Tests.RichTextBoxXml
{
	/// <summary>
	/// Base class for all <see cref="RichTextBoxXmlFormatter"/> test fixtures.
	/// </summary>
	public class RichTextBoxXmlTestFixtureBase
	{
		RichTextBox m_RichTextBox;
		RichTextBoxXmlFormatter m_Formatter;
		
		/// <summary>
		/// Gets the 
		/// </summary>
		public RichTextBox RichTextBoxTestFixture
		{
			get
			{
				return m_RichTextBox;
			}
		}
		
		/// <summary>
		/// Gets the RichTextBox xml formatter.
		/// </summary>
		public RichTextBoxXmlFormatter Formatter
		{
			get
			{
				return m_Formatter;
			}
		}
		
		/// <summary>
		/// Initialises this test fixture.
		/// </summary>
		public void Init( string text )
		{
			m_RichTextBox = new RichTextBox( );
			m_RichTextBox.Multiline = true;
			m_RichTextBox.WordWrap = false;
			m_RichTextBox.Text = text;
			
			m_Formatter = new RichTextBoxXmlFormatter( );
			m_Formatter.Format( m_RichTextBox, 0, m_RichTextBox.Text.Length );
		}	
		
		/// <summary>
		/// Initialises this test.
		/// </summary>
		/// <param name="text">The text to add to the rich text box.</param>
		/// <param name="startIndex">The index to start the formatting
		/// from.</param>
		/// <param name="length">The length of text to format.</param>
		public void Init( string text, int startIndex, int length )
		{
			m_RichTextBox = new RichTextBox( );
			m_RichTextBox.Multiline = true;
			m_RichTextBox.WordWrap = false;
			m_RichTextBox.Text = text;
			
			m_Formatter = new RichTextBoxXmlFormatter( );
			m_Formatter.Format( m_RichTextBox, startIndex, length );
		}
		
		/// <summary>
		/// Gets the text colour at the specified index.
		/// </summary>
		/// <param name="text">The text that should be at the 
		/// specified index.</param>
		/// <param name="index">The character index.</param>
		protected Color GetTextColour( string text, int index )
		{
			m_RichTextBox.Select( index, text.Length );
			
			Assert.AreEqual( text, m_RichTextBox.SelectedText, "Unexpected text at index." );
			
			return m_RichTextBox.SelectionColor;
		}		
	}
}
