//
// SoapTrace.Net - A soap message monitoring utility. 
//
// Copyright (C) 2005 Matthew Ward
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
// Matthew Ward (mrward@users.sourceforge.net)


using NUnit.Framework;
using System;
using System.Drawing;
using System.Windows.Forms;

namespace SoapTrace.Tests.RichTextBoxXml
{
	/// <summary>
	/// Formats a rich text box containing a simple piece of xml with an attribute.
	/// </summary>
	[ TestFixture ]
	public class XmlAttributeFormatTestFixture : RichTextBoxXmlTestFixtureBase
	{
		string Text = @"<Foo name='bar'></Foo>";
		
		/// <summary>
		/// Initialises each test.
		/// </summary>
		[ SetUp ]
		public void Init( )
		{
			base.Init( Text );
		}
		
		/// <summary>
		/// Checks the attribute equals sign colour.
		/// </summary>
		[ Test ]
		public void AttributeEqualsSignColour( )
		{
			Assert.AreEqual( Formatter.MarkupDelimiterColour, GetTextColour( "='", 9 ), 
			                "Attribute equals sign colour is wrong." );
		}
		
		/// <summary>
		/// Checks the attributes end quote colour.
		/// </summary>
		[ Test ]
		public void AttributeEndQuoteColour( )
		{
			Assert.AreEqual( Formatter.MarkupDelimiterColour, GetTextColour( "'", 14 ), 
			                "Attribute end quote colour is wrong." );
		}
		
		/// <summary>
		/// Checks the attributes colour.
		/// </summary>
		[ Test ]
		public void AttributeColour( )
		{
			Assert.AreEqual( Formatter.AttributeColour, GetTextColour( "name", 5 ), 
			                "Attribute colour is wrong." );
		}
		
		/// <summary>
		/// Checks the attributes value colour.
		/// </summary>
		[ Test ]
		public void AttributeValueColour( )
		{
			Assert.AreEqual( Formatter.AttributeValueColour, GetTextColour( "bar", 11 ), 
			                "Attribute value colour is wrong." );
		}
		
		/// <summary>
		/// Checks the element start tag colour.
		/// </summary>
		[ Test ]
		public void StartElementColour( )
		{
			Assert.AreEqual( Formatter.ElementColour, GetTextColour( "Foo", 1 ), 
			                "Start element colour is wrong." );
		}	
	}
}
