//
// SoapTrace.Net - A soap message monitoring utility. 
//
// Copyright (C) 2005 Matthew Ward
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
// Matthew Ward (mrward@users.sourceforge.net)


using NUnit.Framework;
using System;
using System.Drawing;
using System.Windows.Forms;

namespace SoapTrace.Tests.RichTextBoxXml
{
	/// <summary>
	/// Formats a rich text box containing a simple piece of xml like:
	/// <c><Foo></Foo></c>
	/// </summary>
	[ TestFixture ]
	public class XmlElementFormatTestFixture : RichTextBoxXmlTestFixtureBase
	{
		string Text = @"<Foo></Foo>";
		
		/// <summary>
		/// Initialises each test.
		/// </summary>
		[ SetUp ]
		public void Init( )
		{
			base.Init( Text );
		}
		
		/// <summary>
		/// Checks that the text selected after the formatting
		/// is at the end of the text.
		/// </summary>
		[ Test ]
		public void CurrentTextSelection( )
		{
			Assert.AreEqual( Text.Length, RichTextBoxTestFixture.SelectionStart, "Text selection is wrong." );
		}
		
		/// <summary>
		/// Checks that no text is selected.
		/// </summary>
		[ Test ]
		public void CurrentTextSelectionLength( )
		{
			Assert.AreEqual( 0, RichTextBoxTestFixture.SelectionLength, "Text selection length is wrong." );
		}
		
		/// <summary>
		/// Checks that the start element delimiter is the correct
		/// colour.</summary>
		[ Test ]
		public void StartElementDelimiterColour( )
		{
			Assert.AreEqual( Formatter.MarkupDelimiterColour, GetTextColour( "<", 0 ), "Start element delimiter hass incorrect colour" );
		}
		
		/// <summary>
		/// Checks that the end element delimiter is the correct
		/// colour.</summary>
		[ Test ]
		public void EndElementDelimiterColour( )
		{
			Assert.AreEqual( Formatter.MarkupDelimiterColour, GetTextColour( "</", 5 ), "Start element delimiter hass incorrect colour" );
		}
		
		/// <summary>
		/// Checks that the end element's end delimiter is the correct
		/// colour.</summary>
		[ Test ]
		public void EndElementEndDelimiterColour( )
		{
			Assert.AreEqual( Formatter.MarkupDelimiterColour, GetTextColour( ">", 10 ), "Start element delimiter hass incorrect colour" );
		}		
		
		/// <summary>
		/// Checks that the start element's end delimiter is the correct
		/// colour.</summary>
		[ Test ]
		public void StartElementEndDelimiterColour( )
		{
			Assert.AreEqual( Formatter.MarkupDelimiterColour, GetTextColour( ">", 4 ), "Start element's end delimiter hass incorrect colour" );
		}
		
		/// <summary>
		/// Checks the element start tag colour.
		/// </summary>
		[ Test ]
		public void StartElementColour( )
		{
			Assert.AreEqual( Formatter.ElementColour, GetTextColour( "Foo", 1 ), "Start element colour is wrong." );
		}

		/// <summary>
		/// Checks the element end tag colour.
		/// </summary>
		[ Test ]
		public void EndElementColour( )
		{
			Assert.AreEqual( Formatter.ElementColour, GetTextColour( "Foo", 7 ), "End element colour is wrong." );
		}	
	}
}
