//
// SoapTrace.Net - A soap message monitoring utility. 
//
// Copyright (C) 2005 Matthew Ward
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
// Matthew Ward (mrward@users.sourceforge.net)


using NUnit.Framework;
using SoapTrace.Core.Communication;
using System;


namespace SoapTrace.Tests
{
	/// <summary>
	/// Tests the <see cref="SoapRequestAndResponseCollection"/> class.
	/// </summary>
	[ TestFixture ]
	public class SoapRequestResponseCollectionTestFixture
	{
		/// <summary>
		/// Tests that when a request/response pair exist we fail
		/// to add the response to a matching request.
		/// </summary>
		[ Test ]
		public void AddResponseWithExistingRequestResponse( )
		{
			SoapRequestAndResponseCollection Items = new SoapRequestAndResponseCollection( );
					
			ClientId Id = new ClientId( );
			SoapRequestAndResponse RequestAndResponse = new SoapRequestAndResponse( Id, new SoapRequest( ) );
			RequestAndResponse.Response = new SoapResponse( );
			
			Items.Add( RequestAndResponse );
			
			SoapResponse Response = new SoapResponse( );
			
			SoapRequestAndResponse MatchingRequestAndResponse =
				Items.AddResponse( Id, Response );
			
			Assert.IsNull( MatchingRequestAndResponse, "Should not find a match." );
		}
		
		/// <summary>
		/// Tests that when a request/response pair and request with no
		/// response exist with the same client ID we match the second request.
		/// </summary>
		[ Test ]
		public void AddResponseWithMatchingRequestAvailable( )
		{
			SoapRequestAndResponseCollection Items = new SoapRequestAndResponseCollection( );
					
			ClientId Id = new ClientId( );
			SoapRequestAndResponse RequestAndResponse = new SoapRequestAndResponse( Id, new SoapRequest( ) );
			RequestAndResponse.Response = new SoapResponse( );
			
			Items.Add( RequestAndResponse );
			
			RequestAndResponse = new SoapRequestAndResponse( Id, new SoapRequest( ) );
			
			Items.Add( RequestAndResponse );
			
			SoapResponse Response = new SoapResponse( );
			
			SoapRequestAndResponse MatchingRequestAndResponse =
				Items.AddResponse( Id, Response );
			
			Assert.IsNotNull( MatchingRequestAndResponse, "Should find a match." );
			Assert.AreEqual( RequestAndResponse, MatchingRequestAndResponse, "Incorrect object matched." );
		}		
	}
}
