//
// SoapTrace.Net - A soap message monitoring utility. 
//
// Copyright (C) 2005 Matthew Ward
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
// Matthew Ward (mrward@users.sourceforge.net)

using NUnit.Framework;
using SoapTrace.Core.Communication;
using SoapTrace.Core.Diagnostics;
using System;
using System.IO;

namespace SoapTrace.Tests.TcpPacketMonitoring
{
	/// <summary>
	/// Tests the <see cref="TcpPacketMonitor"/> class's handling of a 
	/// client failing to connect.
	/// </summary>
	[ TestFixture ]
	public class FailedToConnectTestFixture
	{
		TcpPacketMonitor Monitor;
		int ClientConnected;
		TcpCommunicationEventArgs EventArgsReceived;
		
		/// <summary>
		/// Initialises each test.
		/// </summary>
		[ TestFixtureSetUp ]
		public void Init( )
		{
			ClientConnected = 0;
			Monitor = new TcpPacketMonitor( "209.171.52.99", 80 );
			Monitor.ClientConnected += new TcpCommunicationEventHandler( OnClientConnected );
			
			StringReader Reader = new StringReader( GetPacketXml( ) );
			PacketLogEntryCollection LogEntries = PacketLogFile.Load( Reader );
			
			foreach( PacketLogEntry Entry in LogEntries )
			{
				Monitor.ProcessPacket( Entry.Packet );
			}
		}
		
		/// <summary>
		/// Checks that the connect event was not triggered.
		/// </summary>
		[ Test ]
		public void ReceivedNoConnectionEvents( )
		{
			Assert.AreEqual( 0, ClientConnected, "Were not expecting any connection events." );
		}
		
		private void OnClientConnected( object sender, TcpCommunicationEventArgs e )
		{
			++ClientConnected;
			EventArgsReceived = e;
		}
		
		/// <summary>
		/// Gets the xml to be read in by the <see cref="PacketLogFile"/>
		/// class.
		/// </summary>
		private string GetPacketXml( )
		{
			return "<Packets>\r\n" +
				"  <Packet Time=\"2005-01-31 19:25:36.37\" ServerFilter=\"1.1.1.1\" PortFilter=\"80\">\r\n" +
				"    <Bytes>00 11 F5 0B 1F 69 00 11 F5 0B 1F 6A 08 00 45 00 00 30 56 F1 40 00 80 06 E0 29 C0 A8 01 03 01 01 01 01 07 28 00 50 B9 9D CA 83 00 00 00 00 70 02 FF FF 33 D9 00 00 02 04 05 B4 01 01 04 02 </Bytes>\r\n" +
				"  </Packet>\r\n" +
				"  <Packet Time=\"2005-01-31 19:25:39.68\" ServerFilter=\"1.1.1.1\" PortFilter=\"80\">\r\n" +
				"    <Bytes>00 11 F5 0B 1F 69 00 11 F5 0B 1F 6A 08 00 45 00 00 30 56 F2 40 00 80 06 E0 28 C0 A8 01 03 01 01 01 01 07 28 00 50 B9 9D CA 83 00 00 00 00 70 02 FF FF 33 D9 00 00 02 04 05 B4 01 01 04 02 </Bytes>\r\n" +
				"  </Packet>\r\n" +
				"  <Packet Time=\"2005-01-31 19:25:45.74\" ServerFilter=\"1.1.1.1\" PortFilter=\"80\">\r\n" +
				"    <Bytes>00 11 F5 0B 1F 69 00 11 F5 0B 1F 6A 08 00 45 00 00 30 56 F5 40 00 80 06 E0 25 C0 A8 01 03 01 01 01 01 07 28 00 50 B9 9D CA 83 00 00 00 00 70 02 FF FF 33 D9 00 00 02 04 05 B4 01 01 04 02 </Bytes>\r\n" +
				"  </Packet>\r\n" +
				"</Packets>";
		}
	}
}
