//
// SoapTrace.Net - A soap message monitoring utility. 
//
// Copyright (C) 2005 Matthew Ward
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
// Matthew Ward (mrward@users.sourceforge.net)

using NUnit.Framework;
using SoapTrace.Core.Diagnostics;
using SoapTrace.Core.Communication;
using System;
using System.IO;

namespace SoapTrace.Tests.TcpPacketMonitoring
{
	/// <summary>
	/// Tests that a disconnection event is not triggered when a Tcp Reset packet
	/// is sent out if the monitor did not get see the connection packets.
	/// </summary>
	[ TestFixture ]
	public class ResetWithNoConnectionTestFixture
	{
		TcpPacketMonitor Monitor;
		int DisconnectCount;
		TcpCommunicationEventArgs EventArgsReceived;
		
		/// <summary>
		/// Initialises each test.
		/// </summary>
		[ TestFixtureSetUp ]
		public void Init( )
		{
			DisconnectCount = 0;
			Monitor = new TcpPacketMonitor( "209.171.52.99", 80 );
			Monitor.ClientDisconnected += new TcpCommunicationEventHandler( OnClientDisconnected );
			
			StringReader Reader = new StringReader( GetPacketXml( ) );
			PacketLogEntryCollection LogEntries = PacketLogFile.Load( Reader );
			
			foreach( PacketLogEntry Entry in LogEntries )
			{
				Monitor.ProcessPacket( Entry.Packet );
			}
		}		
		
		/// <summary>
		/// Checks that we received a disconnect event.
		/// </summary>
		[ Test ]
		public void NoDisconnectEventReceived( )
		{
			Assert.AreEqual( 0, DisconnectCount, "Expected no disconnect event." );
		}
		
		private void OnClientDisconnected( object sender, TcpCommunicationEventArgs e )
		{
			++DisconnectCount;
			EventArgsReceived = e;
		}
		
		/// <summary>
		/// Gets the xml to be read in by the <see cref="PacketLogFile"/>
		/// class.
		/// </summary>
		private string GetPacketXml( )
		{
			return "<Packets>\r\n" +
			"  <Packet Time=\"2005-01-31 18:49:41.80\" ServerFilter=\"209.171.52.99\" PortFilter=\"80\">\r\n" +
			"    <Bytes>00 11 F5 0B 1F 69 00 11 F5 0B 1F 6A 08 00 45 00 00 28 4B 08 40 00 80 06 E8 0D C0 A8 01 03 D1 AB 34 63 06 9C 00 50 BD AA AE 14 6F C1 F2 D5 50 14 00 00 12 D4 00 00 </Bytes>\r\n" +
			"  </Packet>\r\n" +
			"</Packets>";
		}
	}
}
