//
// SoapTrace.Net - A soap message monitoring utility. 
//
// Copyright (C) 2005 Matthew Ward
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
// Matthew Ward (mrward@users.sourceforge.net)


using NUnit.Framework;
using SoapTrace.Core.Formatters;
using System;
using System.Drawing;

namespace SoapTrace.Tests.TextFormatting
{
	/// <summary>
	/// Tests the retrieval of text colour from a single piece of text.
	/// </summary>
	[ TestFixture ]
	public class GetTextColourSingleItemTestFixture
	{
		FormattedText FormattedText;
		string Text = "Foo";
		Color TextColour = Color.Red;
		
		/// <summary>
		/// Initialises each test.
		/// </summary>
		[ SetUp ]
		public void Init( )
		{			
			FormattedText = new FormattedText( TextColour );
			FormattedText.Append( Text );
		}
		
		/// <summary>
		/// Gets the colour for all the text.
		/// </summary>
		[ Test ]
		public void EntireStringColour( )
		{
			Assert.AreEqual( TextColour, FormattedText.GetColour( 0, Text.Length ), "Entire string colour is wrong." );
		}
		
		/// <summary>
		/// Gets the colour for the start of the text.
		/// </summary>
		[ Test ]
		public void StartOfStringColour( )
		{
			Assert.AreEqual( TextColour, FormattedText.GetColour( 0, 1 ), "Start of text is wrong colour." );
		}		
		
		/// <summary>
		/// Gets the colour for the start of the text.
		/// </summary>
		[ Test ]
		public void EndOfStringColour( )
		{
			Assert.AreEqual( TextColour, FormattedText.GetColour( 2, 1 ), "End of text is wrong colour." );
		}			
	}
}
