//
// ${App.Name}
//
// Copyright (C) 2005 Matthew Ward
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
// Matthew Ward (mrward@users.sourceforge.net)

using NUnit.Framework;
using SoapTrace.Core.Formatters;
using System;
using System.Drawing;

namespace SoapTrace.Tests.TextFormatting
{
	/// <summary>
	/// Tests that the correct exception is thrown if the parameters
	/// passed to GetCharIndexFromLine is incorrect.
	/// </summary>
	[ TestFixture ]
	public class InvalidLineInfoTestFixture
	{
		FormattedText FormattedText;
		
		/// <summary>
		/// Initialises each test. 
		/// </summary>
		[ SetUp ]
		public void Init( )
		{
			FormattedText = new FormattedText( Color.Black );
			FormattedText.Append( "Test" );
		}
		
		/// <summary>
		/// Line number is out of range.
		/// </summary>
		[ Test ]
		[ ExpectedException( typeof( ArgumentOutOfRangeException ), 
			ExpectedMessage = "LineNumber cannot be less than zero.\r\nParameter name: lineNumber" ) ]
		public void NegativeLineNumber( )
		{
			FormattedText.GetCharIndexFromLine( -1, 0 );
		}
		
		/// <summary>
		/// Line position is out of range.
		/// </summary>
		[ Test ]
		[ ExpectedException( typeof( ArgumentOutOfRangeException ), 
			ExpectedMessage = "LinePosition cannot be less than zero.\r\nParameter name: linePosition" ) ]
		public void NegativeLinePosition( )
		{
			FormattedText.GetCharIndexFromLine( 0, -1 );
		}	
		
		/// <summary>
		/// Line number does not exist.
		/// </summary>
		[ Test ]
		[ ExpectedException( typeof( ArgumentOutOfRangeException ), 
			ExpectedMessage = "LineNumber does not exist in text.\r\nParameter name: lineNumber" ) ]
		public void InvalidLineNumber( )
		{
			FormattedText.GetCharIndexFromLine( 1, 0 );
		}	
		
	}
}
