//
// ${App.Name}
//
// Copyright (C) 2005 Matthew Ward
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
// Matthew Ward (mrward@users.sourceforge.net)

using NUnit.Framework;
using SoapTrace.Core.Formatters;
using System;
using System.Drawing;

namespace SoapTrace.Tests.TextFormatting
{
	/// <summary>
	/// Tests that the correct exception is thrown if the parameters
	/// are incorrect.
	/// </summary>
	[ TestFixture ]
	public class InvalidSetColourParametersTestFixture
	{
		FormattedText FormattedText;
		
		/// <summary>
		/// Initialises each test. 
		/// </summary>
		[ SetUp ]
		public void Init( )
		{
			FormattedText = new FormattedText( Color.Black );
			FormattedText.Append( "Test" );
		}
		
		/// <summary>
		/// Start index is out of range.
		/// </summary>
		[ Test ]
		[ ExpectedException( typeof( ArgumentOutOfRangeException ), 
			ExpectedMessage = "StartIndex cannot be less than zero.\r\nParameter name: startIndex" ) ]
		public void InvalidStartIndex( )
		{
			FormattedText.SetColour( Color.Red, -1, 2 );
		}
		
		/// <summary>
		/// Length is out of range.
		/// </summary>
		[ Test ]
		[ ExpectedException( typeof( ArgumentOutOfRangeException ), 
			ExpectedMessage = "Length must be greater than zero.\r\nParameter name: length" ) ]
		public void InvalidLength( )
		{
			FormattedText.SetColour( Color.Red, 0, 0 );
		}	
	}
}
