//
// SoapTrace.Net - A soap message monitoring utility. 
//
// Copyright (C) 2005 Matthew Ward
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
// Matthew Ward (mrward@users.sourceforge.net)


using NUnit.Framework;
using SoapTrace.Core.Formatters;
using System;
using System.Drawing;

namespace SoapTrace.Tests.TextFormatting
{
	/// <summary>
	/// Tests the formatting of a piece of text that has a two colours
	/// associated with it.
	/// </summary>
	[ TestFixture ]
	public class TwoColoursTextTestFixture
	{
		FormattedText m_FormattedText;
		string m_Text1 = "Foo";
		string m_Text2 = "Bar";
		Color m_DefaultTextColour = Color.Black;
		Color m_SecondTextColour = Color.Red;
		FormattedTextItem m_FirstTextItem;
		FormattedTextItem m_SecondTextItem;
		
		/// <summary>
		/// Initialises each test.
		/// </summary>
		[ SetUp ]
		public void Init( )
		{
			m_FormattedText = new FormattedText( m_DefaultTextColour );
			m_FormattedText.Append( m_Text1 );
			m_FormattedText.Append( m_Text2, m_SecondTextColour );
			
			m_FirstTextItem = m_FormattedText.Items[ 0 ];
			m_SecondTextItem = m_FormattedText.Items[ 1 ];
		}
		
		/// <summary>
		/// Checks the second item's text colour.
		/// </summary>
		[ Test ]
		public void SecondTextItemTextColour( )
		{
			Assert.AreEqual( m_SecondTextColour, m_SecondTextItem.Colour, 
			                "Second text item's colour is wrong." );
		}
		
		/// <summary>
		/// Checks the first item's text colour.
		/// </summary>
		[ Test ]
		public void FirstTextItemTextColour( )
		{
			Assert.AreEqual( m_DefaultTextColour, m_FirstTextItem.Colour, 
			                "First text item's colour is wrong." );
		}
		
		/// <summary>
		/// Checks the second item's text.
		/// </summary>
		[ Test ]
		public void SecondTextItemText( )
		{
			Assert.AreEqual( m_Text2, m_SecondTextItem.Text, 
			                "Second item's text is wrong." );
		}
		
		/// <summary>
		/// Checks the first item's text.
		/// </summary>
		[ Test ]
		public void FirstTextItemText( )
		{
			Assert.AreEqual( m_Text1, m_FirstTextItem.Text, 
			                "First item's text is wrong." );
		}		
	}
}
