//
// SoapTrace.Net - A soap message monitoring utility. 
//
// Copyright (C) 2005 Matthew Ward
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
// Matthew Ward (mrward@users.sourceforge.net)

using SoapTrace.Core.Communication;
using SoapTrace.Core.Formatters;
using System;

namespace SoapTrace.Tests.Utils
{
	/// <summary>
	/// Represents a custom message formatter object which implements the 
	/// IMessageFormatter interface.
	/// </summary>
	public class MockMessageFormatter : IMessageFormatter
	{
		/// <summary>
		/// The name of this formatter.
		/// </summary>
		public static readonly string FormatterName = "MockMessageFormatter";
		
		/// <summary>
		/// Creates a new instance of the <see cref="MockMessageFormatter"/>
		/// class.
		/// </summary>
		public MockMessageFormatter( )
		{
		}
		
		#region SoapTrace.Core.Formatters.IMessageFormatter interface implementation
		
		/// <summary>
		/// Gets the formatter's name.
		/// </summary>
		public string Name
		{
			get
			{
				return FormatterName;
			}
		}
		
		/// <summary>
		/// Gets whether this formatter is configurable.
		/// </summary>
		public bool IsConfigurable 
		{
			get 
			{
				return false;
			}
		}
		
		/// <summary>
		/// Gets the config editor for this formatter.
		/// </summary>
		public IConfigurationEditor ConfigurationEditor 
		{
			get
			{
				return null;
			}
		}
		
		/// <summary>
		/// Formats the soap request.
		/// </summary>
		/// <param name="server">The host name of the server
		/// or the IP address.</param>
		/// <param name="uri"></param>
		/// <param name="webServiceName"></param>
		/// <param name="webMethod"></param>
		/// <param name="message"></param>
		/// <returns></returns>
		public FormattedText FormatRequest(string server, string uri, string webServiceName, string webMethod, ISoapMessage message) 
		{
			return null;
		}
		
		/// <summary>
		/// Formats the soap response.
		/// </summary>
		/// <param name="server">The host name of the server
		/// or the IP address.</param>
		/// <param name="uri"></param>
		/// <param name="webServiceName"></param>
		/// <param name="webMethod"></param>
		/// <param name="message"></param>
		/// <returns></returns>
		public FormattedText FormatResponse(string server, string uri, string webServiceName, string webMethod, ISoapMessage message) 
		{
			return null;
		}
		
		#endregion
		
	}
}
