//
// SoapTrace.Net - A soap message monitoring utility. 
//
// Copyright (C) 2006 Matthew Ward
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
// Matthew Ward (mrward@users.sourceforge.net)

using NUnit.Framework;
using System;
using System.Drawing;
using System.Windows.Forms;

namespace SoapTrace.Tests.XmlFormatting
{
	/// <summary>
	/// Formats xml containing new lines in an xml element's text.
	/// </summary>
	[ TestFixture ]
	public class NewLinesTestFixture : XmlFormatterTestFixtureBase
	{
		string Text = "<?xml version=\"1.0\" encoding=\"utf-8\"?>" +
			"<soap:Envelope xmlns:soap=\"http://schemas.xmlsoap.org/soap/envelope/\" xmlns:xsi=\"http://www.w3.org/2001/XMLSchema-instance\" xmlns:xsd=\"http://www.w3.org/2001/XMLSchema\">" +
			"<soap:Body>" +
			"<Send xmlns=\"http://soaptrace.net/webservices\">" +
			"<complexType name=\"Name\">" +
			"<Value>Val\nu\ne</Value>" +
			"</complexType>" +
			"</Send>" +
			"</soap:Body>" +
			"</soap:Envelope>";
		
		/// <summary>
		/// Initialises each test.
		/// </summary>
		[ SetUp ]
		public void Init( )
		{
			base.Init( Text );
		}
		
		/// <summary>
		/// Checks the Value element end tag's colour
		/// </summary>
		[ Test ]
		public void EndValueElementColour( )
		{
			int Index = Text.IndexOf( "Value></complexType>" );
			Assert.AreEqual( Formatter.ElementColour, GetTextColour( "Value", Index ), 
			                "Value element end tag colour is incorrect" );
		}	
	}
}

