//
// SoapTrace.Net - A soap message monitoring utility. 
//
// Copyright (C) 2005 Matthew Ward
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
// Matthew Ward (mrward@users.sourceforge.net)

using NUnit.Framework;
using SoapTrace.Core.Formatters;
using System;
using System.Drawing;
using System.Windows.Forms;
using System.Text;

namespace SoapTrace.Tests.XmlFormatting
{
	/// <summary>
	/// Base class for all <see cref="XmlFormatter"/> test fixtures.
	/// </summary>
	public class XmlFormatterTestFixtureBase
	{
		FormattedText m_FormattedText;
		XmlFormatter m_Formatter;
		
		/// <summary>
		/// Gets the FormattedText associated with this test fixture.
		/// </summary>
		public FormattedText FormattedTextTestFixture
		{
			get
			{
				return m_FormattedText;
			}
		}
		
		/// <summary>
		/// Gets the xml formatter.
		/// </summary>
		public XmlFormatter Formatter
		{
			get
			{
				return m_Formatter;
			}
		}
		
		/// <summary>
		/// Initialises this test fixture.
		/// </summary>
		public void Init( string text )
		{
			m_Formatter = new XmlFormatter( );
			m_FormattedText = m_Formatter.Format( text );
		}	
		
		/// <summary>
		/// Gets the text colour at the specified index.
		/// </summary>
		/// <param name="text">The text that should be at the 
		/// specified index.</param>
		/// <param name="index">The character index.</param>
		protected Color GetTextColour( string text, int index )
		{
			string MatchedText = m_FormattedText.Text.Substring( index, text.Length );
			
			Assert.AreEqual( text, MatchedText, "Unexpected text at index." );
			
			return m_FormattedText.GetColour( index, text.Length );
		}		
	}
}
