//
// SoapTrace.Net - A soap message monitoring utility. 
//
// Copyright (C) 2004 Matthew Ward
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
// Matthew Ward (mrward@users.sourceforge.net)

using System;

namespace SoapTrace
{
	/// <summary>
	/// Contains the next piece of text to find and the case
	/// sensitivity when the user hits the "Find Next" button.
	/// </summary>
	public class FindNextEventArgs : EventArgs
	{
		/// <summary>
		/// The search text.
		/// </summary>
		private string m_SearchText = String.Empty;
		
		/// <summary>
		/// Search case sensitive flag.
		/// </summary>
		private bool m_CaseSensitive;
		
		/// <summary>
		/// Creates a new instance of the <see cref="FindNextEventArgs"/>
		/// class.
		/// </summary>
		public FindNextEventArgs( )
		{
		}
		
		/// <summary>
		/// Creates a new instance of the <see cref="FindNextEventArgs"/>
		/// class.
		/// </summary>
		/// <param name="searchText">The text to search for.</param>
		/// <param name="caseSensitive">A flag indicating whether
		/// the search is case sensitive.</param>
		public FindNextEventArgs( string searchText, bool caseSensitive )
		{
			m_CaseSensitive = caseSensitive;
			m_SearchText = searchText;
		}
		
		/// <summary>
		/// Gets the search text.
		/// </summary>
		public string SearchText
		{
			get
			{
				return m_SearchText;
			}
		}
		
		/// <summary>
		/// Gets the case sensitivity.
		/// </summary>
		public bool CaseSensitive
		{
			get
			{
				return m_CaseSensitive;
			}
		}
	}
}
