﻿// 
// SoapTrace.Net - A soap message monitoring utility. 
// 
// Copyright (C) 2004-2009 Matthew Ward
// 
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
// 
// Matthew Ward (mrward@users.sourceforge.net)
// 

using System;
using System.Configuration;
using System.Diagnostics;
using WinPcap.Tests.Utils;

namespace WinPcap.Tests.Configuration
{
	/// <summary>
	/// Holds configuration information for the WinPcap.net tests.
	/// </summary>
	public class TestConfig
	{
		/// <summary>
		/// Private constructor since this is a utility class and all
		/// methods are static.
		/// </summary>
		private TestConfig( )
		{
		}

		/// <summary>
		/// Returns the network interfaces that are expected on this machine.
		/// </summary>
		/// <return>
		/// Returns a collection of network interfaces.
		/// </return>
		public static NetworkInterfaceInfoCollection NetworkInterfaces
		{
			[ DebuggerStepThrough ]
			get
			{
				TestConfigSection ConfigSection = 
					( TestConfigSection )ConfigurationManager.GetSection( "TestConfigSection" );

				return ConfigSection.NetworkInterfaces;
			}
		}

		/// <summary>
		/// Gets the description for the network interface that will be used
		/// in tcp packet capture tests.
		/// </summary>
		public static string TcpPacketCaptureTestNetworkInterfaceDescription
		{
			[ DebuggerStepThrough ]
			get
			{
				return ConfigurationManager.AppSettings[ "deviceDescription" ];
			}
		}

		/// <summary>
		/// Gets the remote server's ip address used for testing packet capture.
		/// </summary>
		public static string RemoteServerIPAddress
		{
			[ DebuggerStepThrough ]
			get
			{
				return ConfigurationManager.AppSettings[ "remoteServerIPAddress" ];
			}
		}

		/// <summary>
		/// Gets the remote server's port used for testing packet capture.
		/// </summary>
		public static int RemoteServerPort
		{
			[ DebuggerStepThrough ]
			get
			{
				string Port = ConfigurationManager.AppSettings[ "remoteServerPort" ];
				return Convert.ToInt32( Port );
			}
		}
	}
}
