//
// SoapTrace.Net - A soap message monitoring utility. 
//
// Copyright (C) 2005 Matthew Ward
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
// Matthew Ward (mrward@users.sourceforge.net)


using NUnit.Framework;
using System;
using WinPcap;
using WinPcap.Tests.Utils;

namespace WinPcap.Tests
{
	/// <summary>
	/// Tests the conversion of <see cref="Packet"/> object which is not a 
	/// tcp packet to a <see cref="TcpPacket"/> object.
	/// </summary>
	[ TestFixture ]
	public class NonTcpPacketToTcpPacketTestFixture
	{
		TcpPacket TcpPacket;
		
		/// <summary>
		/// Initialises each test.
		/// </summary>
		[ SetUp ]
		public void Init( )
		{
			string Data = 
				"0000  00 90 F5 2B 8D 2F 00 40  F4 8C AA 2F 08 00 45 00 \n" +
				"0010  00 30 45 C0 40 00 80 00  23 02 C8 01 01 01 C8 01 \n" +
				"0020  01 02 04 4A 1B 5A D0 22  05 0A 00 00 00 00 70 02 \n" +
				"0030  FF FF FC 48 00 00 02 04  05 B4 01 01 04 02 ";
	
			byte[ ] Bytes = TestUtility.GetBytesFromString( Data ); 

			Packet Packet = new Packet( Bytes );
			
			TcpPacket = TcpPacket.GetTcpPacket( Packet );
		}
		
		/// <summary>
		/// Tests that no tcp packet was created.
		/// </summary>
		[ Test ]
		public void NoPacketCreated( )
		{
			Assert.AreEqual( null, 
				TcpPacket,
				"Should not have a non-null tcp packet" );
		}
	}
}
