//
// SoapTrace.Net - A soap message monitoring utility. 
//
// Copyright (C) 2005 Matthew Ward
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
// Matthew Ward (mrward@users.sourceforge.net)

using NUnit.Framework;
using System;
using WinPcap;
using WinPcap.Tests.Utils;

namespace WinPcap.Tests
{
	/// <summary>
	/// Tests the TcpPacket class when only the tcp bytes are given to it.
	/// </summary>
	[ TestFixture ]
	public class TcpPacketBytesOnlyTestFixture
	{
		TcpPacket TcpPacket;
		
		/// <summary>
		/// Initialises each test.
		/// </summary>
		[ SetUp ]
		public void Init( )
		{
			string Data = 
				"0000  04 4A 1B 5A D0 22 05 0A  00 00 00 00 70 02 FF FF\n" +
				"0010  FC 48 00 00 02 04 05 B4  01 01 04 02 ";

			byte[ ] Bytes = TestUtility.GetBytesFromString( Data ); 

			TcpPacket = new TcpPacket( Bytes );
		}

		/// <summary>
		/// Source IP address.
		/// </summary>
		[ Test ]
		public void SourceAddress( )
		{
			Assert.AreEqual( "0.0.0.0:1098", 
				TcpPacket.SourceAddress.ToString( ),
				"Source IP address mismatch." );
			
		}
		
		/// <summary>
		/// Destination IP address.
		/// </summary>
		[ Test ]
		public void DestinationAddress( )
		{
			Assert.AreEqual( "0.0.0.0:7002", 
				TcpPacket.DestinationAddress.ToString( ),
				"Source IP address mismatch." );
		}
		
		/// <summary>
		/// Source IP port.
		/// </summary>
		[ Test ]
		public void SourcePort( )
		{
			Assert.AreEqual( 1098, TcpPacket.SourcePort, "Source port mismatch." );
		}
		
		/// <summary>
		/// Destination port.
		/// </summary>
		[ Test ]
		public void DestinationPort( )
		{
			Assert.AreEqual( 7002, TcpPacket.DestinationPort, "Destination port mismatch." );
		}
	}
}
