﻿// 
// SoapTrace.Net - A soap message monitoring utility. 
// 
// Copyright (C) 2004 Matthew Ward
// 
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
// 
// Matthew Ward (mrward@users.sourceforge.net)
// 

using System;
using System.Diagnostics;

namespace WinPcap.Tests.Utils
{
	/// <summary>
	/// Holds the information about a NetworkInterfaceAddress.
	/// </summary>
	public class NetworkInterfaceAddressInfo
	{
		/// <summary>
		/// The IP address as a string.
		/// </summary>
		private string m_Address = String.Empty;

		/// <summary>
		/// The netmask as a string.
		/// </summary>
		private string m_NetMask = String.Empty;

		/// <summary>
		/// The broadcast address as a string.
		/// </summary>
		private string m_BroadcastAddress = String.Empty;

		/// <summary>
		/// Creates a new instance of this class.
		/// </summary>
		public NetworkInterfaceAddressInfo( )
		{
		}

		/// <summary>
		/// Gets or sets the network interface's IP address 
		/// (e.g. "190.0.0.1:9000").
		/// </summary>
		public string Address
		{
			[ DebuggerStepThrough ]
			get
			{
				return m_Address;
			}

			[ DebuggerStepThrough ]
			set
			{
				m_Address = value;
			}
		}

		/// <summary>
		/// Gets or sets the netmask of the network interface
		/// </summary>
		public string NetMask
		{
			[ DebuggerStepThrough ]
			get
			{
				return m_NetMask;
			}

			[ DebuggerStepThrough ]
			set
			{
				m_NetMask = value;
			}
		}

		/// <summary>
		/// Gets or sets the broadcast address of the network interface
		/// </summary>
		public string BroadcastAddress
		{
			[ DebuggerStepThrough ]
			get
			{
				return m_BroadcastAddress;
			}

			[ DebuggerStepThrough ]
			set
			{
				m_BroadcastAddress = value;
			}
		}
	}
}
