// 
// SoapTrace.Net - A soap message monitoring utility. 
// 
// Copyright (C) 2004 Matthew Ward
// 
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
// 
// Matthew Ward (mrward@users.sourceforge.net)
// 

using System;
using System.Diagnostics;

namespace WinPcap.Tests.Utils
{
	/// <summary>
	/// Class that holds network interface information.  This
	/// is only used as a simple class that allows the test code
	/// to load network interface information from a config file.
	/// </summary>
	public class NetworkInterfaceInfo
	{
		/// <summary>
		/// Network interface name.
		/// </summary>
		private string m_Name = String.Empty;

		/// <summary>
		/// Network interface description.
		/// </summary>
		private string m_Description = String.Empty;

		/// <summary>
		/// Is loopback device flag.
		/// </summary>
		private bool m_IsLoopback;

		/// <summary>
		/// Network interface address information.
		/// </summary>
		private NetworkInterfaceAddressInfoCollection m_Addresses =
			new NetworkInterfaceAddressInfoCollection( );

		/// <summary>
		/// The data link layer type.
		/// </summary>
		private string m_DataLinkLayerType = String.Empty;

		/// <summary>
		/// Creates a new instance of this class.
		/// </summary>
		public NetworkInterfaceInfo( )
		{
		}

		/// <summary>
		/// Network interface name.
		/// </summary>
		public string Name
		{
			[ DebuggerStepThrough ]
			get
			{
				return m_Name;
			}

			[ DebuggerStepThrough ]
			set
			{
				m_Name = value;
			}
		}

		/// <summary>
		/// Network interface description.
		/// </summary>
		public string Description
		{
			[ DebuggerStepThrough ]
			get
			{
				return m_Description;
			}

			[ DebuggerStepThrough ]
			set
			{
				m_Description = value;
			}
		}

		/// <summary>
		/// Loopback device flag.
		/// </summary>
		public bool IsLoopback
		{
			[ DebuggerStepThrough ]
			get
			{
				return m_IsLoopback;
			}

			[ DebuggerStepThrough ]
			set
			{
				m_IsLoopback = value;
			}
		}

		/// <summary>
		/// Gets or sets the network interface address info
		/// </summary>
		public NetworkInterfaceAddressInfoCollection NetworkInterfaceAddresses
		{
			[ DebuggerStepThrough ]
			get
			{
				return m_Addresses;
			}

			[ DebuggerStepThrough ]
			set
			{
				m_Addresses = value;
			}
		}

		/// <summary>
		/// Gets or sets the data link layer type.
		/// </summary>
		public string DataLinkLayerType
		{
			[ DebuggerStepThrough ]
			get
			{
				return m_DataLinkLayerType;
			}

			[ DebuggerStepThrough ]
			set
			{
				m_DataLinkLayerType = value;
			}
		}
	}
}
