//
// WinPcap.net
//
// Copyright (C) 2005 Matthew Ward
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
// Matthew Ward (mrward@users.sourceforge.net)


using System;

namespace WinPcap
{
	/// <summary>
	/// The data link layer type of the network interface.
	/// </summary>
	public enum DataLinkLayerType : int
	{
		/// <summary>
		/// Data link layer type is unknown.
		/// </summary>
		Unknown = -1,

		/// <summary>
		/// No link-layer encapsulation.
		/// </summary>
		Null = 0,

		/// <summary>
		/// Ethernet (10Mb).
		/// </summary>
		Ethernet = 1,

		/// <summary>
		/// Experimental Ethernet (3Mb).
		/// </summary>
		Ethernet3MB = 2,

		/// <summary>
		/// Amateur Radio AX.25.
		/// </summary>
		AX25 = 3,

		/// <summary>
		/// Proteon ProNET Token Ring.
		/// </summary>
		ProNet = 4,

		/// <summary>
		/// Chaos.
		/// </summary>
		Chaos = 5,

		/// <summary>
		/// IEEE 802 Networks.
		/// </summary>
		Ieee802 = 6,

		/// <summary>
		/// ARCNET, with BSD-style header.
		/// </summary>
		Arcnet = 7,

		/// <summary>
		/// Serial Line IP.
		/// </summary>
		Slip = 8,

		/// <summary>
		/// Point-to-point Protocol.
		/// </summary>
		Ppp = 9,

		/// <summary>
		/// FDDI.
		/// </summary>
		Fddi = 10,

		/// <summary>
		/// LLC/SNAP encapsulated atm.
		/// </summary>
		AtmRfc1483 = 11,

		/// <summary>
		/// Raw IP.
		/// </summary>
		Raw = 12,

		/// <summary>
		/// Linux Classical-IP over ATM.
		/// </summary>
		AtmClip = 19,

		/// <summary>
		/// PPP over serial with HDLC encapsulation.
		/// </summary>
		PppSerial = 50,

		/// <summary>
		/// PPP over Ethernet.
		/// </summary>
		PppEther = 51,

		/// <summary>
		/// Cisco HDLC.
		/// </summary>
		Chdlc = 104,

		/// <summary>
		/// IEEE 802.11 wireless.
		/// </summary>
		Ieee80211 = 105,

		/// <summary>
		/// Linux cooked sockets.
		/// </summary>
		LinuxSll = 113,

		/// <summary>
		/// Apple LocalTalk hardware.
		/// </summary>
		Ltalk = 114,

		/// <summary>
		/// Acorn Econet.
		/// </summary>
		Econet = 115,

		/// <summary>
		/// FC 2625 IP-over-Fibre Channel.
		/// </summary>
		IPOverFC = 122,

		/// <summary>
		/// 802.11 plus WLAN header.
		/// </summary>
		Ieee80211Radio = 127,

		/// <summary>
		/// ARCNET.
		/// </summary>
		ArcnetLinux = 129
	}
}
