//
// WinPcap.net
//
// Copyright (C) 2005 Matthew Ward
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
// Matthew Ward (mrward@users.sourceforge.net)


using System;
using System.Net;

namespace WinPcap
{
	/// <summary>
	/// A network interface address.
	/// </summary>
	public sealed class NetworkInterfaceAddress
	{
		/// <summary>
		/// The network interface's IP address.
		/// </summary>
		IPEndPoint m_Address;

		/// <summary>
		/// The network interface's netmask.
		/// </summary>
		IPEndPoint m_NetMask;

		/// <summary>
		/// The network interface's broadcast address.
		/// </summary>
		IPEndPoint m_BroadcastAddress;

		/// <summary>
		/// Creates a new instance of the <see cref="NetworkInterfaceAddress"/>
		/// class.
		/// </summary>
		public NetworkInterfaceAddress( )
		{
		}
		
		/// <summary>
		/// Gets or sets the IP address.
		/// </summary>
		/// <returns>An IP address end point.</returns>
		public IPEndPoint Address
		{
			get
			{
				return m_Address;
			}
			
			set
			{
				m_Address = value;
			}
		}

		/// <summary>
		/// Gets or sets the netmask.
		/// </summary>
		public IPEndPoint NetMask
		{
			get
			{
				return m_NetMask;
			}
			
			set
			{
				m_NetMask = value;
			}
		}

		/// <summary>
		/// Gets or sets the broadcast address.
		/// </summary>
		public IPEndPoint BroadcastAddress
		{
			get
			{
				return m_BroadcastAddress;
			}
			
			set
			{
				m_BroadcastAddress = value;
			}
		}
	}
}
